@@ -55,7 +55,7 @@ private:
 		cout << "HEADER " << header << "=" << value << endl;
 	}	
 
-	int read(unsigned char *buffer, int len)
+	int read(unsigned char *buffer, size_t len)
 	{
 		URLStream::read((char *)buffer, len);
 		len = gcount();
@@ -72,7 +72,7 @@ private:
 		cout << "END DOCUMENT" << endl;
 	}
 
-	void characters(const unsigned char *text, unsigned int len)
+	void characters(const unsigned char *text, size_t len)
 	{
 		cout << "CHARS=";
 		while(len--)
