@@ -68,7 +68,7 @@ Lockfile::Lockfile(const char *name)
 bool Lockfile::lock(const char *name)
 {
 	char mname[65];
-	char *ext = strrchr(name, '/');
+	char *ext = strrchr((char *)name, '/');
 	
 	if(ext)
 		name = ++ext;
