@@ -50,6 +50,7 @@ using namespace __gnu_cxx;
 
 #ifdef	CCXX_NAMESPACES
 namespace ost {
+using namespace std;
 #endif
 
 bool Mutex::_debug = false;
@@ -256,7 +257,7 @@ void Mutex::enterMutex(void)
 		return;
 	}
 	if(_debug && _name)
-		cerr << Thread::get()->getName() << ": entering" << _name << endl;
+		std::cerr << Thread::get()->getName() << ": entering" << _name << std::endl;
 
 	pthread_mutex_lock(&_mutex);
 	++_level;
@@ -273,7 +274,7 @@ void Mutex::leaveMutex(void)
 	_level = 0;
 	pthread_mutex_unlock(&_mutex);
     if(_debug && _name)
-		cerr << Thread::get()->getName() << ": leaving" << _name << endl;
+		std::cerr << Thread::get()->getName() << ": leaving" << _name << std::endl;
 }
 
 bool Mutex::tryEnterMutex(void)
